<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Nziggumivu</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Nsurifu</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Enteekateeka z&apos;ekiteekateekamadirisa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="26"/>
        <source>Theme</source>
        <translation>Lulyo lw&apos;endabika</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="31"/>
        <source>Appearance</source>
        <translation>Endabika</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="36"/>
        <source>Font</source>
        <translation>Lulyo lw&apos;enkula y&apos;ennukuta</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="41"/>
        <location filename="../obconf.ui" line="102"/>
        <source>Windows</source>
        <translation>Madirisa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="46"/>
        <source>Move &amp; Resize</source>
        <translation>Okukyusa obunene n&apos;okujjulula</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="51"/>
        <source>Mouse</source>
        <translation>Kasongesebwa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="56"/>
        <source>Desktops</source>
        <translation>Awakolerwa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="61"/>
        <source>Margins</source>
        <translation>Emyaagaanya</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="66"/>
        <source>Dock</source>
        <translation>Paaka ya puloguramu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="84"/>
        <source>&amp;Install a new theme...</source>
        <translation>Teekako olulyo lw&apos;endab&amp;ika olupya...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="91"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Kol&amp;awo omuganda gw&apos;olulyo lw&apos;edabika (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="108"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>Amadirisa gasigaza njegoyego ezirabika nga gavuddeko obu&amp;wunde</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="115"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>Kirabike amadirisa &amp;nga gezinga n&apos;okwezingulula okuva mu bufaananyi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="125"/>
        <source>Window Titles</source>
        <translation>Mitwe gy&apos;amadirisa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="131"/>
        <source>Button order:</source>
        <translation>Engobereragana y&apos;amapeesa:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="141"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Kafaananyi ka ku ddirisa
L: Bigambo ebiramba ddirisa (Mutwe)
I: Eppeesa erizingako ddirisa mu kafaananyi (Lizingeko)
M: Eppeesa eriribunisa lutimbe
C: Eppeesa eriggalawo ddirisa
S: Eppeesa erifunza ddirisa mu kabaawo ka mutwe gwa lyo (Lizingire mu mutwe gwa lyo)
D: Eppeesa erireetera ddirisa okulabikira wonna (ku buli awakolerwa)</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="219"/>
        <source>&amp;Active window title: </source>
        <translation>Mutwe gw&apos;eddiris&amp;a erilobedwa: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="229"/>
        <source>&amp;Inactive window title: </source>
        <translation>Mutwe gw&apos;edd&amp;irisa eritalobedwa: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="239"/>
        <source>Menu &amp;header: </source>
        <translation>Mutwe &amp;gwa menyu: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="249"/>
        <source>&amp;Menu Item: </source>
        <translation>Ebisangibwa ku &amp;menyu: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="259"/>
        <source>Active &amp;On-screen display: </source>
        <translation>Menyu eteekateeka enkola y&apos;&amp;olutimbe ekola: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="269"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Me&amp;nyu eteekateeka enkola y&apos;olutimbe etakola: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="283"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Loba eddirisa erise&amp;mbyeyo okulabika</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="290"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>Eddirisa e&amp;ppya lirabikanga akasonga we kali</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="297"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>Eddirisa ppya litondekanga mu ma&amp;kkati g&apos;olutimbe</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="306"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>E&amp;ddirisa eppya we lirabikiranga:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="317"/>
        <source>All monitors</source>
        <translation>Ku ntimbe zonna</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="322"/>
        <source>The active monitor</source>
        <translation>Ku lutimbe olukolerwako</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="327"/>
        <source>The monitor with the mouse</source>
        <translation>Ku lutimbe okuli akasonga</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="332"/>
        <source>Primary monitor</source>
        <translation>Ku lutimbe olusooka</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="342"/>
        <source>Primary Monitor</source>
        <translation>Lutimbe olusooka</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="348"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Olutimbe olusooka Openbox kw&apos;eneeteekanga obuboozi, okugeza ng&apos;akakozesebwa okwetoolola amadirisa.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="358"/>
        <source>Primary &amp;monitor:</source>
        <translation>Oluti&amp;mbe olusooka:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="369"/>
        <source>Fixed Monitor</source>
        <translation>Lutimbe lwa nkalakkalira</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="374"/>
        <source>Active Monitor</source>
        <translation>Lutimbe olukozesebwa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="379"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Olutimbe okuli akasonga</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="387"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Olutimbe olw&apos;enkalakkalira:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="427"/>
        <source>Moving and Resizing Windows</source>
        <translation>Okukyusa obunene n&apos;okujjulula madirisa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="433"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Ebi&amp;ri mu madirisa bisigale nga birabika nga gakyusibwa bunene</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="440"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Ebbanga erimala oku&amp;tambulibwa okuwalula kutandike:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="460"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Obugumu bw&apos;enjegoyego ez&apos;a&amp;wula madirisa:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="480"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Obugumu bw&apos;&amp;enjegoyego ez&apos;awula ntimbe:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="500"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>&amp;Akaseera akamala okuyitawo awakolerwa ne wakyuka:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="520"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>&amp;Eddirisa bwe liwalulwa ne lisolooba ku njegoyego y&apos;olutimbe dda awakolerwa awapya</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="530"/>
        <source>Information Dialog</source>
        <translation>Akaboozi ak&apos;ebifayo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="537"/>
        <location filename="../obconf.ui" line="566"/>
        <source>Centered</source>
        <translation>Mu makkati</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>From left edge</source>
        <translation>Ebipimo okuva ku luyegoyego olwa kkono</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="547"/>
        <source>From right edge</source>
        <translation>Ebipimo okuva ku luyegoyego olwa ddyo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="555"/>
        <source>Fixed &amp;y position:</source>
        <translation>Obusangiro bwa mu busimba (&amp;y):</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="571"/>
        <source>From top edge</source>
        <translation>Ebipimo okuva ku luyegoyego olwa waggulu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="576"/>
        <source>From bottom edge</source>
        <translation>Ebipimo okuva ku luyegoyego olwa wansi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="584"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>Obu&amp;sangiro bw&apos;akaboozi ak&apos;ebifaayo:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="594"/>
        <source>Fixed &amp;x position:</source>
        <translation>Obusangiro bwa mu bumeeza (&amp;x):</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="604"/>
        <source>Show &amp;information dialog:</source>
        <translation>Akaboozi ak&apos;eb&amp;ifaayo lwe kanaalabikiranga:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="629"/>
        <source>When resizing terminal windows</source>
        <translation>Eddirisa ly&apos;ekiwandikiro nga likyusibwa bunene</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="634"/>
        <source>Always</source>
        <translation>Bulijjo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="639"/>
        <source>Never</source>
        <translation>Tekalabikengako</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="648"/>
        <source>Centered on the window</source>
        <translation>Mu makkati g&apos;eddirisa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="653"/>
        <source>Above the window</source>
        <translation>Waggulu w&apos;eddirisa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="658"/>
        <source>Fixed position on screen</source>
        <translation>Mu kifo eky&apos;enkalakkalira ku lutimbe</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="689"/>
        <source>Focusing Windows</source>
        <translation>Okuloba madirisa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="698"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Loba ddirisa nga akasonga kalituuseko</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>Akaseera akayitawo e&amp;ddirisa limale lilobebwe:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="730"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Nga awakolerwa wakyu&amp;sidwa loba ekiri akasonga we keesanze</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="737"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Loba ekiri akasonga gye kasibide nga kalekedd&apos;awo ok&amp;utambula</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="744"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>Eddi&amp;risa akasonga bwe kalituukako liddenga kungulu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>Titlebar</source>
        <translation>Kabaawo ka mutwe gwa ddirisa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="762"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Okukoonerera akabaawo ka mu&amp;twe emirundi ebiri:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="773"/>
        <source>Maximizes the window</source>
        <translation>Kireetera ddirisa okubuna olutimbe</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="778"/>
        <source>Shades the window</source>
        <translation>Kireetera ddirisa okwezingako mu kabaawo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="786"/>
        <source>Double click ti&amp;me:</source>
        <translation>Akasiriikiriro wakati w&apos;obukoo&amp;na obubiri:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="826"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>Akaboozi ak&apos;ebifayo kalabikenga nga awakolerwa wakyu&amp;sibwa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="833"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>Obudde &amp;akaboozi k&apos;ebifayo bwe kalabikira:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="856"/>
        <source>&amp;Number of desktops: </source>
        <translation>Obu&amp;ngi bw&apos;akolerwa: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="879"/>
        <source>&amp;Desktop names:</source>
        <translation>&amp;Mannya g&apos;awakolerwa:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="893"/>
        <source>Desktop Margins</source>
        <translation>Emiwaagaanya gy&apos;awakolerwa</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="899"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Emiwaagaanya gy&apos;awakolerwa bibangirizi ebyawule ku njegoyego z&apos;olutimbe. Amadirisa amapya tegabikka bifo bino, era n&apos;agali mu mbeera ey&apos;okubuna olutimbe tegabituukamu.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="909"/>
        <source>Left:</source>
        <translation>Ogwa kkono:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="923"/>
        <location filename="../obconf.ui" line="944"/>
        <location filename="../obconf.ui" line="965"/>
        <location filename="../obconf.ui" line="986"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="930"/>
        <source>Top:</source>
        <translation>Ogwa waggulu:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="951"/>
        <source>Right:</source>
        <translation>Ogwa ddyo:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="972"/>
        <source>Bottom:</source>
        <translation>Ogwa wansi:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1013"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Paaka ya puloguramu kitundu ky&apos;awakolerwa ekinywereramu butimbe bwa puloguramu ezikolagana nakyo (zi &quot;dockapp&quot;). Puloguramu ekolagana nayo emala okutandika paaka eyo n&apos;erabika, nga enywereddemu akatimbe oba akafaananyi. Puloguramu ezikolagana ne paaka ziyinza okweyambisibwa, okugeza, okuteekawo saawa oba okukolawo ekiringa akakuŋaanizo ka bufaananyi bwa puloguramu ezibumbujja.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1029"/>
        <source>Position</source>
        <translation>Obusangiro</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>&amp;Position:</source>
        <translation>&amp;Obusangiro:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1055"/>
        <source>Top Left</source>
        <translation>Ku kkono waggulu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1060"/>
        <source>Top</source>
        <translation>Waggulu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1065"/>
        <source>Top Right</source>
        <translation>Ku ddyo waggulu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1070"/>
        <source>Left</source>
        <translation>Ku kkono</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1075"/>
        <source>Right</source>
        <translation>Ku ddyo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1080"/>
        <source>Bottom Left</source>
        <translation>Ku kkono wansi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1085"/>
        <source>Bottom</source>
        <translation>Wansi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1090"/>
        <source>Bottom Right</source>
        <translation>Ku ddyo wansi</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1095"/>
        <source>Floating</source>
        <translation>Etengejja</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1109"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Gy&apos;etengejjera:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1134"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1150"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Amadirisa ga puloguramu gasobole okuyingira a&amp;wali paaka</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1157"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Entuula ya paaka: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1171"/>
        <source>Vertical</source>
        <translation>Busimbalaala</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1176"/>
        <source>Horizontal</source>
        <translation>Bumeeza</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1187"/>
        <source>Stacking</source>
        <translation>Empanga ya paaka</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1193"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>P&amp;aaka ereme okubikkibwa kirala kyonna</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1200"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>Paaka esobo&amp;le okubikka n&apos;okubikkibwa madirisa ga puloguramu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1207"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Paaka ereme oku&amp;bikka ddirisa lya puloguramu</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1217"/>
        <source>Hiding</source>
        <translation>Okukisa paaka</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1223"/>
        <source>&amp;Delay before hiding:</source>
        <translation>Akasiriikiriro paaka eryoke ye&amp;kise:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1233"/>
        <source>Delay before &amp;showing:</source>
        <translation>Akasiriikiriro paaka eryoke e&amp;dde:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1263"/>
        <source>&amp;Hide off screen</source>
        <translation>&amp;Paaka yekisenga</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1294"/>
        <source>About</source>
        <translation>Ebifa ku obconf-qt</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../theme.cpp" line="152"/>
        <source>Choose an Openbox theme</source>
        <translation>Londa olulyo lw&apos;endabika ya Openbox</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="67"/>
        <location filename="../desktops.cpp" line="89"/>
        <location filename="../desktops.cpp" line="101"/>
        <source>(Unnamed desktop)</source>
        <translation>(Awakolerwa awatannatumibwa linnya)</translation>
    </message>
    <message>
        <location filename="../mouse.cpp" line="56"/>
        <source>Custom actions</source>
        <translation>Kireetawo ebitegekedwa omukozesa</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="78"/>
        <source>About ObConf-Qt</source>
        <translation>Ebifa ku ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="79"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Puloguramu ey&apos;okuteekateeka enkola n&apos;endabika ya Openbox

Olukusa lw&apos;okukoppolola (c) 2014-2015

Abaawandika:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Puloguramu eno ezimbidwa ku eya ObConf eyawandikibwa bano abaddako.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation>&quot;%1&quot; eteekedwa ku %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; ekoledwa</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Nnemedwa okukola omuganda gw&apos;olulyo lw&apos;endabika &quot;%1&quot;.
Nsanzemu ebizibu bino:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="180"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Nnemedwa okutandika omulimu ogwa &quot;tar&quot;: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Nnemedwa okukolawo tterekero &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>Kirabika &quot;%1&quot; ssi tterekero ery&apos;olulyo lw&apos;endabika ya Openbox</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="187"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Sisobola okupakulula fayiro &quot;%1&quot;.
Tegeka &quot;%2&quot; esobole okuwandikibwamu era libeere tterekero ery&apos;olulyo lw&apos;endabika ya Openbox.
Nsanzemu ebizibu bino:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>ObConf ezeeko kiremya</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Olukusa lw&apos;okukopporola (c) 2003-2008   Dana Jansens
Olukusa lw&apos;okukopporola (c) 2003        Tim Riley
Olukusa lw&apos;okukopporola (c) 2007        Javeed Shaikh
Olukusa lw&apos;okukopporola (c) 2013        Hong Jen Yee (PCMan)

Puloguramu eno ejja nga TEKULI BUVUNAANIRO N&apos;AKATONO
SINGA PULOGURAMU TEKOLA NGA BW&apos;OSUUBIRA OBA
SINGA EREETA EBIZIBU KU KOMPYUTA YO OBA EBIGIRIKO.
Sofutiweya ono taliko bukugire, era oli wa ddembe okuddamu
okumusaasaanya kasita otuukiriza obukwakkulizo obutalibumu.
Okwongera okutangaazibwa soma fayiro COPYING.

</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Enkozesa entuufu eri: obconf [buwayiro] [MUGANDA.obt]

Obuwayiro:
  --help                Kaleetera obconf okukoma ku kuwandika obuyambi buno
  --version             Kaleetera obconf okukoma ku kulaga olwandika lwa yo
  --install MUGANDA.obt Kaleetera obconf okuteekako olulyo lw&apos;endabika oluli mu MUGANDA.obt lutandikirewo okukola
  --archive LULYO       Kaleetera obconf okupakira etterekero ery&apos;olulyo lw&apos;endabika mu muganda gw&apos;olulyo lw&apos;endabika
  --config-file FAYIRO    Kano kalaga obconf okunona olulyo lw&apos;endabika olw&apos;okukozesa mu FAYIRO
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>Akawayiro --install ketaagako agumenti
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>akawayiro --archive ketaagako agumenti
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>Akawayiro --config-file ketaagako agumenti
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="206"/>
        <source>Platform Unsupported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="207"/>
        <source>ObConf-Qt is unsupported under Wayland.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="241"/>
        <location filename="../obconf-qt.cpp" line="256"/>
        <source>Error</source>
        <translation>Kiremya</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="242"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Nnemedwa okufuna fayiro eya rc.xml. Openbox yandiba nga ku sisitemu teyateekebwako bulungi.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="254"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Wazewo kiremya mu kukwataganya fayiro ey&apos;enteekateeka za Openbox n&apos;amateeka ag&apos;empandika.
Fayiro ey&apos;enteekateeka eyo tegoberera mateeka ga XML.

Bubaka: %1</translation>
    </message>
</context>
</TS>
